==================
 Collectd support
==================

`Collectd`_ can use Gnocchi to store its data through a plugin called
`collectd-gnocchi`. It can be installed with _pip_::

     pip install collectd-gnocchi

`Sources and documentation`_ are also available.


.. _`Collectd`: https://www.collectd.org/
.. _`Sources and documentation`: https://github.com/jd/collectd-gnocchi
